import express from 'express';
import Ajv from 'ajv';
import { statusCodes } from '../utils/statusCodes.js';
import { emptySchema } from '../schemas/basic-schemas.js';
import { lockAbl, unlockAbl } from '../abl/lock-abl.js';


const router = express.Router();
const ajv = new Ajv();

router.post('/lock', async (req, res) => {
  const valid = ajv.validate(emptySchema, req.body);
  if (!valid) {
    return res.status(statusCodes.BAD_REQUEST).json({ error: ajv.errors });
  }
  await lockAbl(req, res);
});

router.post('/unlock', async (req, res) => {
  const valid = ajv.validate(emptySchema, req.body);
  if (!valid) {
    return res.status(statusCodes.BAD_REQUEST).json({ error: ajv.errors });
  }
  await unlockAbl(req, res);
});

export { router as lock};
